<?php

namespace 3lineas\Porfolio\Policies;

use Litepie\User\Contracts\UserPolicy;
use 3lineas\Porfolio\Models\Porfolio;

class PorfolioPolicy
{

    /**
     * Determine if the given user can view the porfolio.
     *
     * @param UserPolicy $user
     * @param Porfolio $porfolio
     *
     * @return bool
     */
    public function view(UserPolicy $user, Porfolio $porfolio)
    {
        if ($user->canDo('porfolio.porfolio.view') && $user->isAdmin()) {
            return true;
        }

        return $porfolio->user_id == user_id() && $porfolio->user_type == user_type();
    }

    /**
     * Determine if the given user can create a porfolio.
     *
     * @param UserPolicy $user
     * @param Porfolio $porfolio
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('porfolio.porfolio.create');
    }

    /**
     * Determine if the given user can update the given porfolio.
     *
     * @param UserPolicy $user
     * @param Porfolio $porfolio
     *
     * @return bool
     */
    public function update(UserPolicy $user, Porfolio $porfolio)
    {
        if ($user->canDo('porfolio.porfolio.edit') && $user->isAdmin()) {
            return true;
        }

        return $porfolio->user_id == user_id() && $porfolio->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given porfolio.
     *
     * @param UserPolicy $user
     * @param Porfolio $porfolio
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Porfolio $porfolio)
    {
        return $porfolio->user_id == user_id() && $porfolio->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given porfolio.
     *
     * @param UserPolicy $user
     * @param Porfolio $porfolio
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Porfolio $porfolio)
    {
        if ($user->canDo('porfolio.porfolio.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given porfolio.
     *
     * @param UserPolicy $user
     * @param Porfolio $porfolio
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Porfolio $porfolio)
    {
        if ($user->canDo('porfolio.porfolio.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
