<?php

namespace 3lineas\Porfolio\Providers;

use Illuminate\Support\ServiceProvider;

class PorfolioServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'porfolio');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'porfolio');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('3lineas.porfolio', function ($app) {
            return $this->app->make('3lineas\Porfolio\Porfolio');
        });

        // Bind Porfolio to repository
        $this->app->bind(
            '3lineas\Porfolio\Interfaces\PorfolioRepositoryInterface',
            \3lineas\Porfolio\Repositories\Eloquent\PorfolioRepository::class
        );
        // Bind Category to repository
        $this->app->bind(
            '3lineas\Porfolio\Interfaces\CategoryRepositoryInterface',
            \3lineas\Porfolio\Repositories\Eloquent\CategoryRepository::class
        );

        $this->app->register(\3lineas\Porfolio\Providers\AuthServiceProvider::class);
        
        $this->app->register(\3lineas\Porfolio\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['3lineas.porfolio'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('3lineas/porfolio.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/porfolio')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/porfolio')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
